@@ -1,5 +1,5 @@
 //
-// (C) Copyright 2011-2013 Sergey A. Babkin.
+// (C) Copyright 2011-2014 Sergey A. Babkin.
 // This file is a part of Triceps.
 // See the file COPYRIGHT for the copyright notice and license information
 //
@@ -43,6 +43,18 @@ void mkfdata(FdataVec &fd)
 	fd.push_back(Fdata(true, &v_string, sizeof(v_string)));
 }
 
+// this just makes sure that the code snippet for the doc compiles
+class SampleTracer : public Unit::Tracer
+{           
+public: 
+    virtual void execute(Unit *unit, const Label *label,
+		const Label *fromLabel, Rowop *rop, Unit::TracerWhen when)
+    {   
+        printf("trace %s label '%s' %c\n", Unit::tracerWhenHumanString(when),
+			label->getName().c_str(), Unit::tracerWhenIsBefore(when)? '{' : '}');
+    }
+};
+
 UTESTCASE mkunit(Utest *utest)
 {
 	Autoref<Unit> unit1 = new Unit("my unit");
