@@ -1,5 +1,5 @@
 #
-# (C) Copyright 2011-2013 Sergey A. Babkin.
+# (C) Copyright 2011-2014 Sergey A. Babkin.
 # This file is a part of Triceps.
 # See the file COPYRIGHT for the copyright notice and license information
 #
@@ -9,7 +9,7 @@ package Triceps::SimpleAggregator;
 
 sub CLONE_SKIP { 1; }
 
-our $VERSION = 'v1.0.93';
+our $VERSION = 'v2.0.0';
 
 use Carp;
 
@@ -247,8 +247,8 @@ sub make # (optName => optValue, ...)
 
 			$id++;
 		}
-		$rtRes = Triceps::RowType->new(@rtdefRes)
-			or confess "$myname: invalid result row type definition: $!";
+		$rtRes = Triceps::RowType->new(@rtdefRes);
+			# XXX extended error "$myname: invalid result row type definition: $!";
 	}
 	${$opts->{saveRowTypeTo}} = $rtRes if (defined($opts->{saveRowTypeTo}));
 
@@ -280,11 +280,11 @@ sub make # (optName => optValue, ...)
 	${$opts->{saveComputeTo}} = $compText if (defined($opts->{saveComputeTo}));
 
 	# build and add the aggregator
-	my $agg = Triceps::AggregatorType->new($rtRes, $opts->{name}, undef, $compText, @compArgs)
-		or confess "$myname: failed to build an aggregator type: $! ";
+	my $agg = Triceps::AggregatorType->new($rtRes, $opts->{name}, undef, $compText, @compArgs);
+		# XXX extended error "$myname: failed to build an aggregator type: $! ";
 
-	$idx->setAggregator($agg)
-		or confess "$myname: failed to set the aggregator in the index type: $! ";
+	$idx->setAggregator($agg);
+		# XXX extended error "$myname: failed to set the aggregator in the index type: $! ";
 
 	return $opts->{tabType};
 }
